eggbasket.rest

Package eggbasket :: Module rest |
[show private | hide private]
[frames | no frames]

## Module eggbasket.rest

rest-to-html conversion taken from the Zope core This implementation requires docutils 0.4.0+ from http://docutils.sf.net/

Function Summary
| ``HTML`(src, writer, report_level, stylesheet, input_encoding, output_encoding, language_code, initial_header_level, warnings, settings)` render HTML from a reStructuredText string ...
| ``render`(src, writer, report_level, stylesheet, input_encoding, output_encoding, language_code, initial_header_level, settings)` get the rendered parts of the document the and warning object

Function Details

### HTML(src, writer='html4css1', report_level=1, stylesheet=None, input_encoding='unicode', output_encoding='unicode', language_code='en', initial_header_level=3, warnings=None, settings={})
    render HTML from a reStructuredText string

    - 'src'  -- string containing a valid reST document

    - 'writer' -- docutils writer

    - 'report_level' - verbosity of reST parser

    - 'stylesheet' - Stylesheet to be used

    - 'input_encoding' - encoding of the reST input string

    - 'output_encoding' - encoding of the rendered HTML output

    - 'report_level' - verbosity of reST parser

    - 'language_code' - docutils language

    - 'initial_header_level' - level of the first header tag

    - 'warnings' - will be overwritten with a string containing the warnings

    - 'settings' - dict of settings to pass in to Docutils, with priority

### render(src, writer='html4css1', report_level=1, stylesheet=None, input_encoding='unicode', output_encoding='unicode', language_code='en', initial_header_level=3, settings={}) get the rendered parts of the document the and warning object

Generated by Epydoc 2.1 on Thu Apr 10 17:21:32 2008 | http://epydoc.sf.net